==> adv_varnish-4.0.7.zip: adv_varnish/tests/modules/adv_varnish_block_test/src/Plugin/UserBlocks/Example.php <==
<?php

namespace Drupal\adv_varnish_block_test\Plugin\UserBlocks;

use Drupal\adv_varnish\UserBlockBase;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Provides a language config pages context.
 *
 * @UserBlocks(
 *   id = "example",
 *   label = @Translation("Example"),
 * )
 */
class Example extends UserBlockBase {

  use StringTranslationTrait;

  /**
   * User account interface.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $account;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, AccountProxyInterface $account) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configuration = $configuration;
    $this->account = $account;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user')
    );
  }

  /**
   * User block data for ESI request.
   *
   * @return array
   *   Content for user data block.
   */
  public function userBlockData() {
    $block = [];

    $block['js_settings'] = [
      'user_info' => [
        'user' => [
          'name' => $this->account->getDisplayName(),
          'id' => $this->account->id(),
        ],
      ],
    ];

    $block['content'] = [
      '#block-bartik-account-menu ul .menu-item:first a' => $this->t('Hi, @user', [
        '@user' => $this->account->getDisplayName(),
      ]),
    ];
    $block['tags'] = ['user:' . $this->account->id()];

    return $block;
  }

}

==> adv_varnish-4.0.10.zip: adv_varnish/tests/modules/adv_varnish_block_test/src/Plugin/UserBlocks/Example.php <==
<?php

namespace Drupal\adv_varnish_block_test\Plugin\UserBlocks;

use Drupal\adv_varnish\UserBlockBase;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a language config pages context.
 *
 * @UserBlocks(
 *   id = "example",
 *   label = @Translation("Example"),
 * )
 */
final class Example extends UserBlockBase {

  use StringTranslationTrait;

  /**
   * User account interface.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $account;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, AccountProxyInterface $account) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configuration = $configuration;
    $this->account = $account;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new self(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user')
    );
  }

  /**
   * User block data for ESI request.
   *
   * @return array
   *   Content for user data block.
   */
  public function userBlockData() {
    $block = [];

    $block['js_settings'] = [
      'user_info' => [
        'user' => [
          'name' => $this->account->getDisplayName(),
          'id' => $this->account->id(),
        ],
      ],
    ];

    $block['content'] = [
      '#block-bartik-account-menu ul .menu-item:first a' => $this->t('Hi, @user', [
        '@user' => $this->account->getDisplayName(),
      ]),
    ];
    $block['tags'] = ['user:' . $this->account->id()];

    return $block;
  }

}
